ProfanityApiResponse class

Annotations
  • @freezed

Constructors

ProfanityApiResponse({required bool isProfanity, required double score, String? flaggedFor})
const
factory
ProfanityApiResponse.fromJson(Map<String, dynamic> data)
factory

Properties

copyWith → $ProfanityApiResponseCopyWith<ProfanityApiResponse>
Create a copy of ProfanityApiResponse with the given fields replaced by the non-null parameter values.
no setterinherited
flaggedFor String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isProfanity bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score double
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ProfanityApiResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited